@@ -86,32 +86,47 @@ class Pyprland:
             self.log.critical("No Config file found ! Please create %s", CONFIG_FILE)
             raise PyprError()
 
+    async def _load_single_plugin(self, name, init) -> bool:
+        "Load a single plugin, optionally calling `init`"
+        if "." in name:
+            modname = name
+        elif "external:" in name:
+            modname = name.replace("external:", "")
+        else:
+            modname = f"pyprland.plugins.{name}"
+        try:
+            plug = importlib.import_module(modname).Extension(name)
+            if init:
+                await plug.init()
+                self.queues[name] = asyncio.Queue()
+                if self.tasks:
+                    self.tasks.create_task(self._plugin_runner_loop(name))
+            self.plugins[name] = plug
+        except ModuleNotFoundError as e:
+            self.log.error("Unable to locate plugin called '%s'", name)
+            await notify_info(
+                f'Config requires plugin "{name}" but pypr can\'t find it: {e}'
+            )
+            return False
+        except Exception as e:
+            await notify_info(f"Error loading plugin {name}: {e}")
+            self.log.error("Error loading plugin %s:", name, exc_info=True)
+            raise PyprError() from e
+        return True
+
     async def __load_plugins_config(self, init=True):
         """Loads the plugins mentioned in the config.
         If init is `True`, call the `init()` method on each plugin.
         """
+
+        sys.path.extend(self.config["pyprland"].get("plugins_paths", []))
+
         init_pyprland = "pyprland" not in self.plugins
+
         for name in ["pyprland"] + self.config["pyprland"]["plugins"]:
             if name not in self.plugins:
-                modname = name if "." in name else f"pyprland.plugins.{name}"
-                try:
-                    plug = importlib.import_module(modname).Extension(name)
-                    if init:
-                        await plug.init()
-                        self.queues[name] = asyncio.Queue()
-                        if self.tasks:
-                            self.tasks.create_task(self._plugin_runner_loop(name))
-                    self.plugins[name] = plug
-                except ModuleNotFoundError as e:
-                    self.log.error("Unable to locate plugin called '%s'", name)
-                    await notify_info(
-                        f'Config requires plugin "{name}" but pypr can\'t find it: {e}'
-                    )
+                if not await self._load_single_plugin(name, init):
                     continue
-                except Exception as e:
-                    await notify_info(f"Error loading plugin {name}: {e}")
-                    self.log.error("Error loading plugin %s:", name, exc_info=True)
-                    raise PyprError() from e
             if init:
                 try:
                     await self.plugins[name].load_config(self.config)
@@ -125,7 +140,7 @@ class Pyprland:
                     raise PyprError() from e
         if init_pyprland:
             plug = self.plugins["pyprland"]
-            plug.set_commands(reload=self.load_config)
+            plug.set_commands(reload=self.load_config)  # type: ignore
 
     async def load_config(self, init=True):
         """loads the configuration (new plugins will be added & config updated)
@@ -135,11 +150,27 @@ class Pyprland:
         await self.__open_config()
         assert self.config
         await self.__load_plugins_config(init=init)
+        if self.config["pyprland"].get("colored_handlers_log", True):
+            self.log_handler = (  # pylint: disable=attribute-defined-outside-init
+                self.colored_log_handler
+            )
+        else:
+            self.log_handler = (  # pylint: disable=attribute-defined-outside-init
+                self.plain_log_handler
+            )
+
+    def plain_log_handler(self, plugin, name, params):
+        "log a handler method without color"
+        plugin.log.debug(f"{name}{params}")
+
+    def colored_log_handler(self, plugin, name, params):
+        "log a handler method with color"
+        color = 33 if name.startswith("run_") else 30
+        plugin.log.debug(f"\033[{color};1m%s%s\033[0m", name, params)
 
     async def _run_plugin_handler(self, plugin, full_name, params):
         "Runs a single handler on a plugin"
-        color = 33 if full_name.startswith("run_") else 30
-        plugin.log.debug(f"\033[{color};1m%s%s\033[0m", full_name, params)
+        self.log_handler(plugin, full_name, params)
         try:
             await getattr(plugin, full_name)(*params)
         except AssertionError as e:
@@ -315,6 +346,11 @@ async def run_daemon():
 async def run_client():
     "Runs the client (CLI)"
     manager = Pyprland()
+
+    if sys.argv[1] == "version":
+        print("2.1.4-23")  # Automatically updated version
+        return
+
     if sys.argv[1] in ("--help", "-h", "help"):
         await manager.load_config(init=False)
 
