@@ -73,24 +73,6 @@ def get_XY(place, main_mon, other_mon):
     return (x, y)
 
 
-async def apply_monitor_position(
-    monitors, screenid: str, pos_x: int, pos_y: int, logger=None
-) -> None:
-    "Apply the configuration change"
-
-    command = ["wlr-randr"]
-    monitor = [mon for mon in monitors if mon["name"] == screenid][0]
-
-    monitor["x"] = pos_x
-    monitor["y"] = pos_y
-
-    command.extend(["--output", screenid, "--pos", f"{pos_x},{pos_y}"])
-    txt_command = " ".join(command)
-    if logger:
-        logger.debug(txt_command)
-    await asyncio.create_subprocess_shell(txt_command)
-
-
 def build_graph(config):
     "make a sorted graph based on the cleaned_config"
     graph = defaultdict(list)
@@ -109,6 +91,7 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
     _mon_by_pat_cache: dict[str, dict] = {}
 
     async def on_reload(self):
+        self._clear_mon_by_pat_cache()
         if self.cast_bool(self.config.get("startup_relayout"), True):
             await self.run_relayout()
 
@@ -119,6 +102,8 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
     ):
         "Recompute & apply every monitors's layout"
 
+        self._clear_mon_by_pat_cache()
+
         monitors = cast(list[dict], await self.hyprctlJSON("monitors"))
 
         cleaned_config = self.resolve_names(monitors)
@@ -128,54 +113,27 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
             self.log.debug("No configuration item is applicable")
         graph = build_graph(cleaned_config)
         need_change = self._update_positions(monitors, graph, cleaned_config)
+        every_monitor = {v["name"]: v for v in await self.hyprctlJSON("monitors all")}
         if need_change:
             trim_offset(monitors)
 
-            command = ["wlr-randr"]
             for monitor in sorted(monitors, key=lambda x: x["x"] + x["y"]):
-                command.extend(
-                    [
-                        "--output",
-                        monitor["name"],
-                        "--pos",
-                        f'{monitor["x"]},{monitor["y"]}',
-                    ]
+                name = monitor["name"]
+                this_mon = every_monitor[name]
+                resolution = f"{this_mon['width']}x{this_mon['height']}@{this_mon['refreshRate']}"
+                scale = this_mon["scale"]
+                position = f"{monitor['x']}x{monitor['y']}"
+
+                await self.hyprctl(
+                    f"monitor {name},{resolution},{position},{scale}", "keyword"
                 )
-            txt_cmd = " ".join(command)
-            self.log.info(txt_cmd)
-            proc = await asyncio.create_subprocess_shell(
-                txt_cmd, stderr=asyncio.subprocess.PIPE
-            )
-            assert proc.stderr
-            err = await proc.stderr.read()
-            if err:
-                self.log.debug(err)
 
     # Event handlers
 
-    async def event_monitoradded(self, monitor_name) -> None:
+    async def event_monitoradded(self, _) -> None:
         "Triggers when a monitor is plugged"
         await asyncio.sleep(self.config.get("new_monitor_delay", 1.0))
-
-        if self.cast_bool(self.config.get("full_relayout"), True):
-            await self.run_relayout()
-        else:
-            monitors = cast(list, await self.hyprctlJSON("monitors"))
-
-            assert monitors
-
-            for mon in monitors:
-                if mon["name"].startswith(monitor_name):
-                    mon_info = mon
-                    break
-            else:
-                self.log.warning("Monitor %s not found", monitor_name)
-                return
-
-            default_command = self.config.get("unknown")
-            val = await self._place_single_monitor(mon_info, monitors)
-            if val and default_command:
-                await asyncio.create_subprocess_shell(default_command)
+        await self.run_relayout()
 
     # Utils
 
@@ -183,16 +141,18 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
         "clear the cache"
         self._mon_by_pat_cache = {}
 
-    def _get_mon_by_pat(self, pat, database):
+    def _get_mon_by_pat(self, pat, description_db, name_db):
         """Returns a (plugged) monitor object given its pattern or none if not found"""
         cached = self._mon_by_pat_cache.get(pat)
-        if cached:
-            return cached
-        for full_descr in database:
-            if pat in full_descr:
-                cached = database[full_descr]
+        if cached is None:
+            cached = name_db.get(pat)
+            if cached is None:
+                for full_descr in description_db:
+                    if pat in full_descr:
+                        cached = description_db[full_descr]
+                        break
+            if cached:
                 self._mon_by_pat_cache[pat] = cast(dict[str, dict], cached)
-                break
         return cached
 
     _flipped_positions = {
@@ -214,54 +174,6 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
         "rightendof": "leftendof",
     }
 
-    def _get_rules(self, mon_name, placement):
-        "build a list of matching rules from the config"
-        for pattern, config in placement.items():
-            matched = pattern == mon_name
-            for position, descr_list in config.items():
-                if isinstance(descr_list, str):
-                    descr_list = [descr_list]
-                for descr in descr_list:
-                    lp = clean_pos(position)
-                    if matched or descr == mon_name:
-                        yield (
-                            lp if matched else self._flipped_positions[lp],
-                            descr,
-                            f"{pattern} {config}",
-                        )
-
-    async def _place_single_monitor(
-        self,
-        mon_info: dict[str, int | float | str | list],
-        monitors: list[dict[str, Any]],
-    ):
-        "place a given monitor according to config"
-
-        mon_name: str = cast(str, mon_info["name"])
-        monitors_by_name = {m["name"]: m for m in monitors}
-        self._clear_mon_by_pat_cache()
-        matched = False
-
-        cleaned_config = self.resolve_names(monitors)
-        for place, other_screen, rule in self._get_rules(
-            mon_info["name"], cleaned_config
-        ):
-            other_mon = monitors_by_name.get(other_screen)
-
-            if other_mon:
-                matched = True
-                pos = get_XY(place, mon_info, other_mon)
-                if pos:
-                    x, y = pos
-                    self.log.info("Will place %s @ %s,%s (%s)", mon_name, x, y, rule)
-                    await apply_monitor_position(
-                        monitors, mon_name, x, y, logger=self.log
-                    )
-                else:
-                    self.log.error("Unknown position type: %s (%s)", place, rule)
-
-        return matched
-
     def _update_positions(self, monitors, graph, config):
         "Apply configuration to monitors_by_name using graph"
         monitors_by_name = {m["name"]: m for m in monitors}
@@ -306,9 +218,9 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
         placement_rules = deepcopy(self.config.get("placement", {}))
         monitors_by_descr = {m["description"]: m for m in monitors}
         cleaned_config: dict[str, dict[str, Any]] = {}
-        plugged_monitors = {m["name"] for m in monitors}
+        plugged_monitors = {m["name"]: m for m in monitors}
         for descr1, placement in placement_rules.items():
-            mon = self._get_mon_by_pat(descr1, monitors_by_descr)
+            mon = self._get_mon_by_pat(descr1, monitors_by_descr, plugged_monitors)
             if not mon:
                 continue
             name1 = mon["name"]
@@ -320,7 +232,7 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
                     descr_list = [descr_list]
                 resolved = []
                 for p in descr_list:
-                    r = self._get_mon_by_pat(p, monitors_by_descr)
+                    r = self._get_mon_by_pat(p, monitors_by_descr, plugged_monitors)
                     if r:
                         resolved.append(r["name"])
                 if resolved:
