@@ -15,7 +15,7 @@ from .interface import Plugin
 from ..common import state, CastBoolMixin
 
 DEFAULT_MARGIN = 60  # in pixels
-AFTER_SHOW_INHIBITION = 0.2  # 200ms of ignorance after a show
+AFTER_SHOW_INHIBITION = 0.3  # 300ms of ignorance after a show
 DEFAULT_HYSTERESIS = 0.4  # In seconds
 
 # Helper functions {{{
@@ -23,9 +23,9 @@ DEFAULT_HYSTERESIS = 0.4  # In seconds
 invert_dimension = {"width": "height", "height": "width"}
 
 
-def get_space_identifier(obj):
+def get_space_identifier():
     "Returns a unique object for the workspace + monitor combination"
-    return (obj.workspace, obj.monitor)
+    return (state.active_workspace, state.active_monitor)
 
 
 def convert_coords(logger, coords, monitor):
@@ -180,11 +180,15 @@ class Scratch(CastBoolMixin):  # {{{
 
     async def get_auto_offset(self, monitor=None):
         "Get au automatic offset value computed from client size"
+        width, height = self.client_info["size"]
+        margin = self.conf.get("margin", DEFAULT_MARGIN)
         if monitor is None:
-            monitor = await get_focused_monitor_props(self.log)
+            monitor = await get_focused_monitor_props(
+                self.log, name=self.conf.get("force_monitor")
+            )
         return map(
             int,
-            [monitor["width"] / monitor["scale"], monitor["height"] / monitor["scale"]],
+            [(width + margin) / monitor["scale"], (height + margin) / monitor["scale"]],
         )
 
     async def initialize(self, ex):
@@ -439,37 +443,34 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
         self.scratches.setState(scratch, "configured")
         animation_type: str = scratch.conf.get("animation", "fromTop").lower()
         defined_class: str = scratch.conf.get("class", "")
-        if animation_type and defined_class:
-            monitor = await get_focused_monitor_props(self.log)
+        if defined_class:
+            monitor = await self.get_focused_monitor_props(
+                name=scratch.conf.get("force_monitor")
+            )
             width, height = convert_coords(
                 self.log, scratch.conf.get("size", "80% 80%"), monitor
             )
 
-            margin_x = (monitor["width"] - width) // 2
-            margin_y = (monitor["height"] - height) // 2
-
-            t_pos = {
-                "fromtop": f"{margin_x} -200%",
-                "frombottom": f"{margin_x} 200%",
-                "fromright": f"200% {margin_y}",
-                "fromleft": f"-200% {margin_y}",
-            }[animation_type]
-
             ipc_commands = [
                 f"windowrule float,^({defined_class})$",
+                f"windowrule workspace special:scratch_{scratch.uid} silent,^({defined_class})$",
             ]
 
-            if not self.cast_bool(scratch.conf.get("lazy")):
-                ipc_commands.append(
-                    f"windowrule workspace special:scratch_{scratch.uid} silent,^({defined_class})$"
-                )
-
             if not self.cast_bool(scratch.conf.get("preserve_aspect")):
-                ipc_commands.extend(
-                    [
-                        f"windowrule move {t_pos},^({defined_class})$",
-                        f"windowrule size {width} {height},^({defined_class})$",
-                    ]
+                if animation_type:
+                    margin_x = (monitor["width"] - width) // 2
+                    margin_y = (monitor["height"] - height) // 2
+
+                    t_pos = {
+                        "fromtop": f"{margin_x} -200%",
+                        "frombottom": f"{margin_x} 200%",
+                        "fromright": f"200% {margin_y}",
+                        "fromleft": f"-200% {margin_y}",
+                    }[animation_type]
+                    ipc_commands.append(f"windowrule move {t_pos},^({defined_class})$")
+
+                ipc_commands.append(
+                    f"windowrule size {width} {height},^({defined_class})$"
                 )
 
             await self.hyprctl(ipc_commands, "keyword")
@@ -479,8 +480,9 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
         if `class_match` is enabled, will use the class, else the process's PID will be used.
         """
         self.log.info("==> Wait for %s spawning", item.uid)
-        for loop_count in range(1, 8):
-            await asyncio.sleep(loop_count**2 / 10.0)
+        interval_range = [0.1] * 10 + [0.2] * 20 + [0.5] * 15
+        for interval in interval_range:
+            await asyncio.sleep(interval)
             is_alive = await item.isAlive()
 
             # skips the checks if the process isn't started (just wait)
@@ -626,11 +628,7 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
                         del self._hysteresis_tasks[scratch.uid]
                     self.log.debug("Canceled previous task for %s", uid)
             else:
-                if (
-                    scratch.visible
-                    and scratch.conf.get("unfocus") == "hide"
-                    and not self.scratches.hasState(scratch, "transition")
-                ):
+                if scratch.visible and scratch.conf.get("unfocus") == "hide":
                     last_shown = scratch.meta.get("last_shown", 0)
                     if last_shown + AFTER_SHOW_INHIBITION > time.time():
                         self.log.debug(
@@ -650,8 +648,9 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
                         )
 
                         async def _task(scratch, uid):
-                            await self._hysteresis_tasks[scratch.uid]
-                            del self._hysteresis_tasks[scratch.uid]
+                            if scratch.uid in self._hysteresis_tasks:
+                                await self._hysteresis_tasks[scratch.uid]
+                                del self._hysteresis_tasks[scratch.uid]
                             if state.active_window == scratch.full_address:
                                 self.log.debug(
                                     "Skipped hidding %s because client got the focus back",
@@ -722,11 +721,10 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
             )
             return
 
-        is_visible = (
-            first_scratch.visible
-            and first_scratch.space_identifier == get_space_identifier(self)
+        is_visible = first_scratch.visible and (
+            first_scratch.conf.get("force_monitor")
+            or first_scratch.space_identifier == get_space_identifier()
         )
-
         tasks = []
 
         for uid in uids:
@@ -734,37 +732,47 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
             if not item:
                 self.log.warning("%s is not configured", uid)
             else:
-                self.log.debug("%s is visible = %s", uid, item.visible)
+                self.log.debug(
+                    "%s is visible = %s (but %s)", uid, item.visible, is_visible
+                )
                 if is_visible and await item.isAlive():
                     tasks.append(partial(self.run_hide, uid))
                 else:
                     tasks.append(partial(self.run_show, uid))
         await asyncio.gather(*(asyncio.create_task(t()) for t in tasks))
 
-    async def _anim_hide(self, animation_type, scratch):
-        "animate hiding a scratchpad"
+    async def get_offsets(self, scratch, monitor=None):
+        "Return offset from config or compute one"
         offset = scratch.conf.get("offset")
-        if offset is None:
-            if "size" not in scratch.client_info:
-                await self.updateScratchInfo(scratch)
+        if offset:
+            return offset, offset
+        return await scratch.get_auto_offset(monitor)
 
-            off_x, off_y = await scratch.get_auto_offset()
+    async def _hide_transition(self, scratch, monitor):
+        "animate hiding a scratchpad"
+
+        animation_type: str = scratch.conf.get("animation", "").lower()
+        if not animation_type:
+            return False
+
+        await self.updateScratchInfo(scratch)
+
+        off_x, off_y = await self.get_offsets(scratch, monitor)
         await self._slide_animation(animation_type, scratch, off_x, off_y)
+        return True
 
     async def _slide_animation(self, animation_type, scratch, off_x, off_y):
         "Slides the window `offset` pixels respecting `animation_type`"
         addr = "address:" + scratch.full_address
         if animation_type == "fromtop":
-            await self.hyprctl(f"movewindowpixel 0 -{off_y},{addr}")
+            await self.hyprctl(f"movewindowpixel 0 {-off_y},{addr}")
         elif animation_type == "frombottom":
             await self.hyprctl(f"movewindowpixel 0 {off_y},{addr}")
         elif animation_type == "fromleft":
-            await self.hyprctl(f"movewindowpixel -{off_x} 0,{addr}")
+            await self.hyprctl(f"movewindowpixel {-off_x} 0,{addr}")
         elif animation_type == "fromright":
             await self.hyprctl(f"movewindowpixel {off_x} 0,{addr}")
 
-        if self.scratches.hasState(scratch, "transition"):
-            return  # abort sequence
         await asyncio.sleep(0.2)  # await for animation to finish
 
     async def run_show(self, uid) -> None:
@@ -780,10 +788,6 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
 
         self.focused_window_tracking[uid] = state.active_window
 
-        if not item:
-            self.log.warning("%s is not configured", uid)
-            return
-
         self.log.info("Showing %s", uid)
         was_alive = await item.isAlive()
         if not await self.ensure_alive(uid):
@@ -804,30 +808,33 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
         await item.initialize(self)
 
         item.visible = True
-        item.space_identifier = get_space_identifier(self)
-        monitor = await get_focused_monitor_props(self.log)
+        item.space_identifier = get_space_identifier()
+        monitor = await self.get_focused_monitor_props(
+            name=item.conf.get("force_monitor")
+        )
+
         assert monitor
         assert item.full_address, "No address !"
 
-        self.scratches.setState(item, "transition")
-        item.monitor = monitor["name"]
         await self._show_transition(item, monitor, was_alive)
+        item.monitor = monitor["name"]
 
     async def _show_transition(self, item, monitor, was_alive):
         "perfoms the transition to visible state"
         animation_type = item.conf.get("animation", "").lower()
         wrkspc = monitor["activeWorkspace"]["id"]
+        item.meta["last_shown"] = time.time()
         # Start the transition
         await self.hyprctl(
             [
-                f"moveworkspacetomonitor special:scratch_{item.uid} {item.monitor}",
+                f"moveworkspacetomonitor special:scratch_{item.uid} {monitor['name']}",
                 f"movetoworkspacesilent {wrkspc},address:{item.full_address}",
                 f"alterzorder top,address:{item.full_address}",
             ]
         )
         preserve_aspect = self.cast_bool(item.conf.get("preserve_aspect"))
-        should_set_aspect = not (
-            preserve_aspect and was_alive
+        should_set_aspect = (
+            not (preserve_aspect and was_alive) or item.monitor != state.active_monitor
         )  # not aspect preserving or it's newly spawned
         if should_set_aspect:
             await self._fix_size(item, monitor)
@@ -837,11 +844,12 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
             position_fixed = await self._fix_position(item, monitor)
         if not position_fixed:
             if animation_type:
-                if preserve_aspect and was_alive:
+                # NOTE: refactor, use single animation method
+                if preserve_aspect and was_alive and not should_set_aspect:
                     if "size" not in item.client_info:
                         await self.updateScratchInfo(item)
 
-                    ox, oy = await item.get_auto_offset(monitor)
+                    ox, oy = await self.get_offsets(item, monitor)
                     await self._slide_animation(animation_type, item, -ox, -oy)
                 else:
                     margin = item.conf.get("margin", DEFAULT_MARGIN)
@@ -854,15 +862,14 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
                     )
                     await self.hyprctl(command)
             else:
-                await self.notify_error(
-                    f"No position and no animation provided for {item.uid}, don't know where to place it."
+                self.log.warning(
+                    "No position and no animation provided for %s, don't know where to place it.",
+                    item.uid,
                 )
 
         await self.hyprctl(f"focuswindow address:{item.full_address}")
-        await asyncio.sleep(0.2)  # ensure some time for events to propagate
-        # Transition ended
-        self.scratches.clearState(item, "transition")
         item.meta["last_shown"] = time.time()
+        item.meta["monitor_info"] = monitor
 
     async def _fix_size(self, item, monitor):
         "apply the `size` config parameter"
@@ -910,18 +917,15 @@ class Extension(CastBoolMixin, Plugin):  # pylint: disable=missing-class-docstri
             return
         scratch.visible = False
         self.log.info("Hiding %s", uid)
-        animation_type: str = scratch.conf.get("animation", "").lower()
-        if animation_type:
-            await self._anim_hide(animation_type, scratch)
+        animated = await self._hide_transition(scratch, scratch.meta["monitor_info"])
 
-        if not self.scratches.hasState(scratch, "transition"):
-            await self.hyprctl(
-                f"movetoworkspacesilent special:scratch_{uid},address:{scratch.full_address}"
-            )
+        await self.hyprctl(
+            f"movetoworkspacesilent special:scratch_{uid},address:{scratch.full_address}"
+        )
 
         if (
             not autohide
-            and animation_type
+            and animated
             and uid in self.focused_window_tracking
             and self.cast_bool(scratch.conf.get("restore_focus"), True)
         ):  # focus got lost when animating
